@@ -1,9 +1,10 @@
 import typer
-
 from dotenv import load_dotenv
 
 from kclii.database.database import Base, engine
 from kclii.modules.profiles import profiles
+from scripts.scripts import install_scripts
+
 import kclii.modules.profiles.models
 
 load_dotenv()
@@ -11,11 +12,22 @@ app = typer.Typer(pretty_exceptions_enable=False)
 app.add_typer(profiles.app, name="profile")
 
 
+@app.command()
+def init():
+    print("Init configurations")
+    install_scripts()
+
+
 @app.command()
 def hello(name: str = ""):
     print(f"Welcome sr! {name}")
 
 
+@app.command()
+def version() -> None:
+    print("0.1.3")
+
+
 if __name__ == "__main__":
     Base.metadata.create_all(engine)
     app()
